@@ -1,12 +1,18 @@
 import abc
-from typing import Optional, Type
+from typing import Optional, Type, cast
 import random
 import asyncio
 import ssl
 
+from pytmi.message import make_privmsg
+
 from pytmi.stream import *
 
 
+PING_MESSAGE = b"PING :tmi.twitch.tv\r\n"
+PONG_MESSAGE = b"PONG :tmi.twitch.tv\r\n"
+
+
 # Default client limits
 # Those are arbitrary value
 MAX_RETRY = 8
@@ -20,14 +26,11 @@ class TmiClient(TmiBaseClient):
     """Asynchronous client for handling IRC-TMI streams and messages."""
 
     def __init__(
-        self, ssl: bool = True, stream: Optional[Type[TmiBaseStream]] = None
+        self, use_ssl: bool = True, stream: Type[TmiBaseStream] = TmiStream
     ) -> None:
-        if stream == None:
-            self.__stream_type = TmiStream
-        else:
-            self.__stream_type = stream
+        self.__stream_type = stream
 
-        self.__ssl = ssl
+        self.__use_ssl = use_ssl
         self.__stream = self.__stream_type()
 
         self.__logged: bool = False
@@ -68,7 +71,7 @@ class TmiClient(TmiBaseClient):
         await self.login_oauth(token, nick, retry=retry)
 
     async def __login(self, token: str, nick: str) -> None:
-        if self.__ssl:
+        if self.__use_ssl:
             await self.__stream.connect(
                 TMI_SERVER, TMI_SERVER_SSLPORT, ssl_ctx=ssl.create_default_context()
             )
@@ -130,7 +133,7 @@ class TmiClient(TmiBaseClient):
         if not self.__logged:
             raise AttributeError("Not logged in")
 
-        if self.__joined != None:
+        if self.__joined is not None:
             self.part(self.__joined)
 
         await self.__stream.disconnect()
@@ -143,7 +146,7 @@ class TmiClient(TmiBaseClient):
         if not channel.startswith("#"):
             channel = "#" + channel
 
-        self.__joined_channel = channel
+        self.__joined = channel
 
         command = "JOIN " + channel + "\r\n"
         await self.__stream.write_buf(command.encode())
@@ -152,15 +155,18 @@ class TmiClient(TmiBaseClient):
         if not self.__logged:
             raise AttributeError("Not logged in")
 
-        if channel == None:
-            channel = self.__joined_channel
-            if channel == None:
+        if channel is None:
+            channel = self.__joined
+            if channel is None:
                 raise AttributeError("Unspecified channel")
 
+        # TODO: Is this cast really necessary?
+        channel = cast(str, channel)
+
         if not channel.startswith("#"):
             channel = "#" + channel
 
-        self.__joined_channel = None
+        self.__joined = None
 
         command = "PART " + channel + "\r\n"
         await self.__stream.write_buf(command.encode())
@@ -169,16 +175,18 @@ class TmiClient(TmiBaseClient):
         if not self.__logged:
             raise AttributeError("Not logged in")
 
-        if channel == None:
-            channel = self.__joined_channel
-            if channel == None:
+        if channel is None:
+            channel = self.__joined
+            if channel is None:
                 raise AttributeError("Unspecified channel")
 
+        # TODO: Is this cast really necessary?
+        channel = cast(str, channel)
+
         if not channel.startswith("#"):
             channel = "#" + channel
 
-        command = "PRIVMSG " + channel + " :" + message + "\r\n"
-        await self.__stream.write_buf(command.encode())
+        await self.__stream.write_buf(make_privmsg(channel, message))
 
     async def get_privmsg(self) -> str:
         if not self.__logged:
@@ -186,8 +194,8 @@ class TmiClient(TmiBaseClient):
 
         line = await self.__stream.read_buf()
 
-        if line == b"PING :tmi.twitch.tv\r\n":
-            self.__stream.write_buf(b"PONG :tmi.twitch.tv\r\n")
+        if line == PING_MESSAGE:
+            self.__stream.write_buf(PONG_MESSAGE)
             line = await self.__stream.read_buf()
 
         return line.decode()
