@@ -1,7 +1,16 @@
 from typing import Optional, Union, Dict, Any
+from abc import ABC, abstractproperty
 
 
-class TmiMessage(object):
+class TmiBaseMessage(ABC):
+    """Base message abstraction for IRC messages with TMI tags."""
+
+    @abstractproperty
+    def valid(self) -> bool:
+        """Return `True` if the message was parsed successfully, otherwise `False`."""
+
+
+class TmiMessage(TmiBaseMessage):
     """Message abstraction for IRC messages with TMI tags."""
 
     def __init__(self, message: Union[str, bytes]) -> None:
@@ -47,7 +56,7 @@ class TmiMessage(object):
     def __parse_tags(self, tags: str) -> None:
         """Parse the given tags populating the `tags` property with a key-value dict."""
 
-        if tags == None:
+        if tags is None:
             return
 
         tags_list = tags.split(";")
@@ -55,7 +64,7 @@ class TmiMessage(object):
         for tag in tags_list:
             key, value = tag.split("=", 1)
 
-            norm = value
+            norm: Any = value
 
             if value.isspace() or value == "":
                 norm = None
@@ -91,11 +100,13 @@ class TmiMessage(object):
         return self.__left
 
     @property
-    def parsed(self) -> bool:
-        """Return `True` if the message was parsed correctly, otherwise `False`."""
+    def valid(self) -> bool:
         return self.__parsed
 
 
-__all__ = [
-    "TmiMessage",
-]
+def make_privmsg(channel: str, message: str) -> bytes:
+    """Format and encode an IRC private message"""
+    return "PRIVMSG #{} : {}\r\n".format(channel, message).encode()
+
+
+__all__ = ["TmiMessage", "make_privmsg"]
